[Xfce4-commits] <xfce4-screenshooter:master> Horodate is not an English word. Timestamp is.

Jérôme Guelfucci noreply at xfce.org
Fri Oct 30 23:56:02 CET 2009


Updating branch refs/heads/master
         to 643422a0529227045c2348434f7d14e9fe831028 (commit)
       from a4450eaad93187a325fcd6c4c2138a6d3230a4ca (commit)

commit 643422a0529227045c2348434f7d14e9fe831028
Author: Jérôme Guelfucci <jeromeg at xfce.org>
Date:   Fri Oct 30 23:55:00 2009 +0100

    Horodate is not an English word. Timestamp is.

 lib/screenshooter-actions.c |    4 ++--
 lib/screenshooter-dialogs.c |   20 ++++++++++----------
 lib/screenshooter-dialogs.h |    2 +-
 lib/screenshooter-global.h  |    2 +-
 lib/screenshooter-utils.c   |    6 +++---
 5 files changed, 17 insertions(+), 17 deletions(-)

diff --git a/lib/screenshooter-actions.c b/lib/screenshooter-actions.c
index 0d77661..9facc08 100644
--- a/lib/screenshooter-actions.c
+++ b/lib/screenshooter-actions.c
@@ -86,7 +86,7 @@ gboolean screenshooter_action_idle (ScreenshotData *sd)
       save_location = screenshooter_save_screenshot (sd->screenshot,
                                                      sd->screenshot_dir,
                                                      sd->title,
-                                                     sd->horodate,
+                                                     sd->timestamp,
                                                      TRUE);
 
       if (save_location)
@@ -111,7 +111,7 @@ gboolean screenshooter_action_idle (ScreenshotData *sd)
         screenshooter_save_screenshot (sd->screenshot,
                                        temp_dir_uri,
                                        sd->title,
-                                       sd->horodate,
+                                       sd->timestamp,
                                        FALSE);
 
       if (screenshot_path != NULL)
diff --git a/lib/screenshooter-dialogs.h b/lib/screenshooter-dialogs.h
index 1ae4957..cbc2703 100644
--- a/lib/screenshooter-dialogs.h
+++ b/lib/screenshooter-dialogs.h
@@ -42,7 +42,7 @@ GtkWidget *screenshooter_region_dialog_new  (ScreenshotData *sd,
 gchar     *screenshooter_save_screenshot    (GdkPixbuf      *screenshot,
                                              const gchar    *directory,
                                              const gchar    *title,
-                                             gboolean        horodate,
+                                             gboolean        timestamp,
                                              gboolean        save_dialog);
 
 
diff --git a/lib/screenshooter-global.h b/lib/screenshooter-global.h
index 41dfc0f..08b825f 100644
--- a/lib/screenshooter-global.h
+++ b/lib/screenshooter-global.h
@@ -48,7 +48,7 @@ typedef struct
   gint action;
   gboolean plugin;
   gboolean action_specified;
-  gboolean horodate;
+  gboolean timestamp;
   gchar *screenshot_dir;
   gchar *title;
   gchar *app;
diff --git a/lib/screenshooter-utils.c b/lib/screenshooter-utils.c
index bdd3694..58cba8c 100644
--- a/lib/screenshooter-utils.c
+++ b/lib/screenshooter-utils.c
@@ -61,7 +61,7 @@ screenshooter_read_rc_file (const gchar *file, ScreenshotData *sd)
   gint region = FULLSCREEN;
   gint action = SAVE;
   gint show_mouse = 1;
-  gboolean horodate = TRUE;
+  gboolean timestamp = TRUE;
   gchar *screenshot_dir = g_strdup (default_uri);
   gchar *title = g_strdup (_("Screenshot"));
   gchar *app = g_strdup ("none");
@@ -81,7 +81,7 @@ screenshooter_read_rc_file (const gchar *file, ScreenshotData *sd)
           region = xfce_rc_read_int_entry (rc, "region", FULLSCREEN);
           action = xfce_rc_read_int_entry (rc, "action", SAVE);
           show_mouse = xfce_rc_read_int_entry (rc, "show_mouse", 1);
-          horodate = xfce_rc_read_bool_entry (rc, "horodate", TRUE);
+          timestamp = xfce_rc_read_bool_entry (rc, "timestamp", TRUE);
 
           g_free (app);
           app = g_strdup (xfce_rc_read_entry (rc, "app", "none"));
@@ -110,7 +110,7 @@ screenshooter_read_rc_file (const gchar *file, ScreenshotData *sd)
   sd->region = region;
   sd->action = action;
   sd->show_mouse = show_mouse;
-  sd->horodate = horodate;
+  sd->timestamp = timestamp;
   sd->screenshot_dir = screenshot_dir;
   sd->title = title;
   sd->app = app;



More information about the Xfce4-commits mailing list
diff --git a/lib/screenshooter-dialogs.c b/lib/screenshooter-dialogs.c
index f44710d..79269c4 100644
--- a/lib/screenshooter-dialogs.c
+++ b/lib/screenshooter-dialogs.c
@@ -61,7 +61,7 @@ cb_delay_spinner_changed           (GtkWidget          *spinner,
 static gchar
 *generate_filename_for_uri         (const gchar        *uri,
                                     const gchar        *title,
-                                    gboolean            horodate);
+                                    gboolean            timestamp);
 static void
 cb_combo_active_item_changed       (GtkWidget          *box,
                                     ScreenshotData     *sd);
@@ -200,7 +200,7 @@ static void cb_delay_spinner_changed (GtkWidget *spinner, ScreenshotData *sd)
 
 
 
 /* If @horodate is true, generates a file name @title - date - hour - n.png,
  * where n is the lowest integer such as this file does not exist in the @uri
  * folder.
  * Else, generates a file name @title-n.png, where n is the lowest integer 
@@ -208,13 +208,13 @@ static void cb_delay_spinner_changed (GtkWidget *spinner, ScreenshotData *sd)
  * 
  * @uri: uri of the folder for which the filename should be generated.
  * @title: the main title of the file name.
  * @horodate: whether the date and the hour should be appended to the file name.
  *
  * returns: the filename or NULL if *uri == NULL.
 */
 static gchar *generate_filename_for_uri (const gchar *uri,
                                          const gchar *title,
-                                         gboolean horodate)
+                                         gboolean timestamp)
 {
   gboolean exists = TRUE;
   GFile *directory;
@@ -233,7 +233,7 @@ static gchar *generate_filename_for_uri (const gchar *uri,
 
   TRACE ("Get the folder corresponding to the URI");
   directory = g_file_new_for_uri (uri);
-  if (!horodate)
+  if (!timestamp)
     base_name = g_strconcat (title, ".png", NULL);
   else
     base_name = g_strconcat (title, " - ", date, " - ", current_time, ".png", NULL);
@@ -256,7 +256,7 @@ static gchar *generate_filename_for_uri (const gchar *uri,
       const gchar *extension =
         g_strdup_printf ("-%d.png", i);
 
-      if (!horodate)
+      if (!timestamp)
          base_name = g_strconcat (title, extension, NULL);
        else
          base_name = g_strconcat (title, " - ", date, " - ", current_time, extension, NULL);
@@ -1033,12 +1033,12 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
 
 
 /* Saves the @screenshot in the given @directory using
  * @title and @horodate to generate the file name.
  *
  * @screenshot: a GdkPixbuf containing the screenshot.
  * @directory: the save location.
  * @title: the title of the screenshot.
  * @horodate: whether the date and the hour should be added to
  * the file name.
  *
  * Returns: a string containing the path to the saved file.
@@ -1047,10 +1047,10 @@ gchar
 *screenshooter_save_screenshot (GdkPixbuf *screenshot,
                                 const gchar *directory,
                                 const gchar *title,
-                                gboolean horodate,
+                                gboolean timestamp,
                                 gboolean save_dialog)
 {
-  const gchar *filename = generate_filename_for_uri (directory, title, horodate);
+  const gchar *filename = generate_filename_for_uri (directory, title, timestamp);
   gchar *save_uri = g_build_filename (directory, filename, NULL);
   gchar *result;
 
@@ -200,7 +200,7 @@ static void cb_delay_spinner_changed (GtkWidget *spinner, ScreenshotData *sd)
 
 
-/* If @horodate is true, generates a file name @title - date - hour - n.png,
+/* If @timestamp is true, generates a file name @title - date - hour - n.png,
  * where n is the lowest integer such as this file does not exist in the @uri
  * folder.
@@ -208,13 +208,13 @@ static void cb_delay_spinner_changed (GtkWidget *spinner, ScreenshotData *sd)
  * @uri: uri of the folder for which the filename should be generated.
  * @title: the main title of the file name.
- * @horodate: whether the date and the hour should be appended to the file name.
+ * @timestamp: whether the date and the hour should be appended to the file name.
  *
  * returns: the filename or NULL if *uri == NULL.
@@ -1033,12 +1033,12 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
 
 /* Saves the @screenshot in the given @directory using
- * @title and @horodate to generate the file name.
+ * @title and @timestamp to generate the file name.
  *
  * @screenshot: a GdkPixbuf containing the screenshot.
@@ -1033,12 +1033,12 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
  * @directory: the save location.
  * @title: the title of the screenshot.
- * @horodate: whether the date and the hour should be added to
+ * @timestamp: whether the date and the hour should be added to
  * the file name.
  *